<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="xml" encoding="UTF-8" />
    
  <!-- Default stage table names -->
  <xsl:variable name="ST_EVENT_DOMAIN_PREDICATES">DS_EVENT_DOMAIN_PREDICATES</xsl:variable>
  <!-- Joined Tables -->
  <xsl:variable name="ST_PREDICATE_JOIN_VALUES">DS_PREDICATE_JOIN_VALUES</xsl:variable>
 
  <!-- Staging Field names -->
  <xsl:variable name="event_domain_key_field">event_domain_key</xsl:variable>
  <xsl:variable name="predicate_name_field">predicate_name</xsl:variable>
  <xsl:variable name="predicate_type_field">predicate_type</xsl:variable>
  <xsl:variable name="ranking_field">ranking</xsl:variable>
  <xsl:variable name="important_field">important</xsl:variable>
  
  <!-- Event Domain Predicate.. Table Level -->
  <xsl:template match="event_domain_predicate">
    <bean>
      <xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
      </xsl:attribute>
      <xsl:call-template name="inject_staging_datasource" />
      <xsl:call-template name="choose_staging_table_name">
        <xsl:with-param name="default_name" select="$ST_EVENT_DOMAIN_PREDICATES" />
      </xsl:call-template>
      <property name="dataSynchronizationService">
        <ref bean="dataSyncEventDomainPredicateService" />
      </property>
      <xsl:call-template name="inject_report_keeper"/>
      <!-- Row Synchronizer -->
      <xsl:call-template name="row_synchronizer">
        <xsl:with-param name="data_synchronization_service">dataSyncEventDomainPredicateService</xsl:with-param>
        <xsl:with-param name="default_table" select="$ST_EVENT_DOMAIN_PREDICATES" />
        <xsl:with-param name="sync_class" select="$owned_object_row_synchronizer"/>
        <xsl:with-param name="owner_field" select="$event_domain_key_field" />
        <xsl:with-param name="pre_commit_validator">predicatePreCommitValidator</xsl:with-param>
      </xsl:call-template>
    </bean>
  </xsl:template>

  <!-- Event Domain Predicate .. Field Level -->
  <xsl:template match="event_domain_key">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">predicates</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$referenceKeyTypeMapper" />
      <xsl:with-param name="mapper_properties">dataSyncEventDomainService</xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="predicate_name">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">name</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="predicate_type">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">type</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$customTypeTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="ranking">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">rankingNumber</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$integerTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="important">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">important</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$booleanTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <!-- Joined Table Predicate Values -->
  <xsl:variable name="predicate_value_field">predicate_value</xsl:variable>
  <xsl:template match="predicate_value">
    <entry>
      <xsl:attribute name="key">
        <xsl:value-of select="name()" />
      </xsl:attribute>
      <bean>
        <xsl:call-template name="core_field_properties">
          <xsl:with-param name="synchronizer_class" select="$collection_fieldsync_class"/>
          <xsl:with-param name="model_property_name">listValues</xsl:with-param>
          <xsl:with-param name="mapper_class" select="$hashSetTypeMapper"/>
        </xsl:call-template>

        <property name="joinedTableSynchronizer">
          <bean>
            <xsl:call-template name="joined_table_synchronizer">
              <xsl:with-param name="joined_table_name" select="$ST_PREDICATE_JOIN_VALUES"/>
              <xsl:with-param name="parent_external_key">PREDICATE_EXTERNAL_KEY</xsl:with-param>
              <xsl:with-param name="model_property_name">listValues</xsl:with-param>
              <xsl:with-param name="child_external_key">PREDICATE_VALUE</xsl:with-param>
              <xsl:with-param name="mapper_class" select="$predicateListValueTypeMapper" />
            </xsl:call-template>
          </bean>
        </property>
      </bean>
    </entry>
  </xsl:template>
 
</xsl:stylesheet>
